/*
 * MIDI player for UNIX (midi.h)
 *
 * 19th, Dec. 1994. by Takanari HAYAMA
 *
 */

#include "mf.h"

struct midihead {
  int division;
  int ntrks;
  int num;
  int denom;
  int clocks;
  int qnotes;
}; 

struct midi {
  int type;
  unsigned long ctime;
  int n;
  unsigned char *data;
};

/* MIDI COMMANDS */
#define MIDI_NOTEOFF    0x80    /* Note off */
#define MIDI_NOTEON     0x90    /* Note on */
#define MIDI_PRESSURE   0xa0    /* Polyphonic key pressure */
#define MIDI_CONTROL    0xb0    /* Control change */
#define MIDI_PROGRAM    0xc0    /* Program change */
#define MIDI_CHANPRES   0xd0    /* Channel pressure */
#define MIDI_PITCHB     0xe0    /* Pitch wheel change */
#define MIDI_SYSEX      0xf0    /* System exclusive data */

/* META-EVENT MESSAGE TYPES */
#define META_SEQNUM             0x00    /* Sequence number */
#define META_TEXT               0x01    /* Text event */
#define META_COPYRIGHT          0x02    /* Copyright notice */
#define META_SEQNAME            0x03    /* Sequence/track name */
#define META_INSTNAME           0x04    /* Instrument name */
#define META_LYRIC              0x05    /* Lyric */
#define META_MARKER             0x06    /* Marker */
#define META_CUEPT              0x07    /* Cue point */
#define META_EOT                0x2f    /* End of track */
#define META_TEMPO              0x51    /* Set tempo */
#define META_SMPTE              0x54    /* SMPTE offset */
#define META_TIMESIG            0x58    /* Time signature */
#define META_KEYSIG             0x59    /* Key signature */
#define META_SEQSPEC            0x7f    /* Sequencer-specific event */

#ifndef _MYMIDI_C_
  extern void initmidi();
  extern void openmf();
  extern int myread();
  extern int fatal();
  extern int read_header();
  extern int midi_starttrack();
  extern void midi_inc();
  extern void make_chunk();
  extern int midi_note_on();
  extern int midi_note_off();
  extern int midi_pressure();
  extern int midi_control();
  extern int midi_program();
  extern int midi_chanpressure();
  extern int midi_pitchbend();
  extern int midi_sqspecific();
  extern int midi_text();
  extern int midi_tempo();
  extern int midi_timesig();
  extern int midi_eot();
  extern int midi_sysex();
  extern int midi_endtrack();
#else
#endif
